import { SchemaValidators } from "@keymanapp/common-types";
;
;
;
export function parseMapping(mapping) {
    if (!SchemaValidators.default.displayMap(mapping)) 
    /* c8 ignore next 3 */
    {
        throw new Error(JSON.stringify(SchemaValidators.default.displayMap.errors));
    }
    let map = {};
    for (let item of mapping.map) {
        map[item.str] = String.fromCharCode(parseInt(item.pua, 16));
    }
    return map;
}
function cleanString(s) {
    s = s.replace(/\u25cc/g, '');
    return s.trim();
}
function remap(text, map) {
    if (map[text.trim()]) {
        return map[text.trim()];
    }
    text = cleanString(text);
    if (map[text]) {
        return map[text];
    }
    return text;
}
export function remapVisualKeyboard(vk, map) {
    let dirty = false;
    for (let key of vk.keys) {
        if (!key.text) {
            continue;
        }
        const text = remap(key.text, map);
        dirty = dirty || text != key.text;
        key.text = text;
    }
    return dirty;
}
export function remapTouchLayout(source, map) {
    let dirty = false;
    const scanKey = (key) => {
        if (!key.text) {
            return;
        }
        if (key.text.length > 2 && key.text[0] == '*' && key.text[key.text.length - 1] == '*') {
            // Don't touch '*special*' key captions
            return;
        }
        const text = remap(key.text, map);
        dirty = dirty || text != key.text;
        key.text = text;
    };
    const scanPlatform = (platform) => {
        if (!platform) {
            return;
        }
        for (let layer of platform.layer) {
            for (let row of layer.row) {
                for (let key of row.key) {
                    scanKey(key);
                    let f;
                    for (f in key.flick ?? {}) {
                        scanKey(key.flick[f]);
                    }
                    for (let sk of key.sk ?? []) {
                        scanKey(sk);
                    }
                    for (let mt of key.multitap ?? []) {
                        scanKey(mt);
                    }
                }
            }
        }
    };
    scanPlatform(source.desktop);
    scanPlatform(source.phone);
    scanPlatform(source.tablet);
    return dirty;
}
//# sourceMappingURL=osk.js.map